@@ -4,9 +4,4 @@ use serde::Deserialize;
 pub enum BackendType {
     Github(crate::config::GithubConfig),
     Gitlab(crate::config::GitlabConfig),
-}
-
-#[derive(Clone, Deserialize, Debug)]
-pub struct BackendConfig {
-    pub r#type: BackendType,
-}
+}
\ No newline at end of file
